import pytest
from rest_framework import status

from rest_framework.reverse import reverse


@pytest.mark.django_db
def test_add_sponsor(client):
    data = {
        "feide_id": "sponsor@example.org",
        "first_name": "Test",
        "last_name": "Sponsor",
    }

    post_response = client.post(reverse("sponsor-list"), data=data)

    assert post_response.status_code == status.HTTP_201_CREATED

    response_data = post_response.json()
    list_response = client.get(
        reverse("sponsor-detail", kwargs={"id": response_data["id"]})
    )
    list_response_data = list_response.json()

    assert list_response_data["feide_id"] == data["feide_id"]
    assert list_response_data["first_name"] == data["first_name"]
    assert list_response_data["last_name"] == data["last_name"]


@pytest.mark.django_db
def test_sponsor_guest_list(client, sponsor_guy, person_foo_role):
    url = reverse("sponsor_guests-list", kwargs={"sponsor_id": sponsor_guy.id})
    guests_for_sponsor = client.get(url).json()["results"]

    assert len(guests_for_sponsor) == 1
    assert guests_for_sponsor[0]["id"] == person_foo_role.person_id


@pytest.mark.django_db
def test_sponsor_empty_guest_list(client, sponsor_guy):
    url = reverse("sponsor_guests-list", kwargs={"sponsor_id": sponsor_guy.id})
    guests_for_sponsor = client.get(url).json()["results"]

    assert len(guests_for_sponsor) == 0
